@@ -23,6 +23,8 @@ from magicapi.Decorators.helpers import async_safe
 
 def run_in_background_no_dynamo(f=None, background_url: str = None):
     if not f:
+        if background_url and g.settings.local:
+            background_url = None
         return functools.partial(
             run_in_background_no_dynamo, background_url=background_url
         )
@@ -64,6 +66,8 @@ def run_in_background_no_dynamo(f=None, background_url: str = None):
 
 def run_in_background(f=None, background_url: str = None):
     if not f:
+        if background_url and g.settings.local:
+            background_url = None
         return functools.partial(run_in_background, background_url=background_url)
     router_path = f"/run_in_background/{f.__name__}"
     new_r = APIRouter()
