@@ -53,6 +53,20 @@ def add_tasks_and_process_time_middleware(new_app):
         return response
 
 
+def add_process_time_middleware(new_app):
+    @new_app.middleware("http")
+    async def add_process_time(request: Request, call_next):
+        start_time = time.time()
+        print("url path", request.url.path, "***url", request.url)
+        if "aws.context" in request.scope:
+            context = request.scope["aws.context"]
+            if hasattr(context, "serverless_sdk"):
+                context.serverless_sdk.set_endpoint(request.url.path)
+        response = await call_next(request)
+        response.headers["X-Process-Time"] = str(time.time() - start_time)
+        return response
+
+
 def add_hello_world_testing_route(new_app):
     @new_app.get("/", tags=["boilerplate"])
     def read_root():
@@ -64,10 +78,13 @@ def add_hello_world_testing_route(new_app):
         }
 
 
-def add_addons(new_app):
+def add_addons(new_app, only_server: bool = False):
     add_cors(new_app)
     add_sentry(new_app)
-    add_tasks_and_process_time_middleware(new_app)
+    if not only_server:
+        add_tasks_and_process_time_middleware(new_app)
+    else:
+        add_process_time_middleware(new_app)
     add_hello_world_testing_route(new_app)
 
 
@@ -90,7 +107,7 @@ def set_settings(settings=MagicSettings()):
     g.settings = settings
 
 
-def create_app(config_settings=MagicSettings()):
+def create_app(config_settings=MagicSettings(), only_server: bool = False):
     set_settings(config_settings)
     print("creating_app", datetime.datetime.now())
     new_app = FastAPI(
@@ -100,9 +117,12 @@ def create_app(config_settings=MagicSettings()):
     )
 
     g.app = new_app
-    add_background_tasks()
-    make_magic_router()
-    add_addons(g.app)
+    if not only_server:
+        add_background_tasks()
+    if not only_server:
+        make_magic_router()
+
+    add_addons(g.app, only_server)
 
     config_firestore(g.settings.service_account_name)
 
